# Step by Step deployment guide

- Development
  - Edit CHANGELOG.md
    - [ ] Rename [Unreleased] to [$VERSION]
    - [ ] Reintroduce [Unreleased]
    - [ ] Fix [Unreleased] and add [$VERSION] named link at the end of CHANGELOG.md

  - [ ] (Optional) Bump versions of
        - clarin-dspace-app: `DSPACE_APP_VERSION` in docker/clarin-dspace/dockerfiles/Earthfile
        - lindat-common: settings in docker/clarin-dspace/dockerfiles/commul-customization/variable.makefile

  - Commit to master to make sure that the master branch is clean and all
    commits are pushed to origin
    - [ ] `git commit -m"Bump version to $VERSION"`
    - [ ] `git tag X.Y.Z-rcR`
    - [ ] `./release.sh`
    - [ ] # Use the `sed` command at the end to adapt the k8s files
          # ./start- ... ./stop- or kubectl edit 

- Prepare a release
  - Make a copy of DEPLOYMENT.md
    - [ ] cp DEPLOYMENT.md DEPLOYMENT-$VERSION.md
  
  - [ ] Check versions are non-rc candidates:
        - clarin-dspace-app: `DSPACE_APP_VERSION` in docker/clarin-dspace/dockerfiles/Earthfile
        - lindat-common: settings in docker/clarin-dspace/dockerfiles/commul-customization/variable.makefile

  - [ ] Check CHANGELOG.md has up-to-date edits

  - Check that the master branch is clean and all commits are pushed to origin
    - [ ] git status
    - [ ] git push
 
  - Merge changes into stable
    - [ ] git checkout stable
    - [ ] git merge --no-ff master

  - [ ] (Optional) You can now deploy stable to dspace-dev
        This depends on your workflow, for example, you man have already tested
        from master. In any case, `./release.sh` picks up the tag from `git tag`,
        i.e. *before* every `./release.sh` there should be a `git tag`. 
        During testing this `tag` should always be of type `X.Y.Z.-rcR`.

        ```
        ./release.sh
        # Use the `sed` command at the end to adapt the k8s files
        # ./start- ... ./stop- or kubectl edit 
        ```

  - Check that the stable branch is clean and all commits are pushed to origin
    - [ ] git status
    - [ ] git push

  - Create a new version branch for this release
    - [ ] git checkout -b ver-$VERSION

  - Adapt clarin-dev and dspace-dev & commit changes, tag version, make a
    release, and push changes
    - [ ] ./clarindev2clarin.sh
    - [ ] git commit -m"Add clarindev2clarin.sh changes"
    - [ ] git tag -a $VERSION -s (-u $GPG_ID_HASH)
          "
          Tag version $VERSION 

          Copy&Paste relevant CHANGELOG.md
          " 
      - [ ] Make sure to remove '#' for 'TITLE lines' from commit message
          (otherwise, they will be ignored)
    - [ ] ./release.sh
    - [ ] # Use the `sed` command at the end to adapt the k8s files
    - [ ] git commit -m"Bump version to $VERSION" 
    - [ ] git push origin ver-$VERSION
 
  - Merge ver-$VERSION into production 
    - [ ] git checkout production
    - [ ] git merge --strategy-option=theirs --squash ver-$VERSION
          "
          Squashing commits of branch 'v$VERSION' into production

          Commits
          ...
          "
    - [ ] git push origin production
    - [ ] git push --tags

  - Deploy production to --namespace=dspace and go back to master
    - [ ] cd ../kubernetes
    - [ ] ./stop_kube.sh
    - [ ] ./start_kube.sh
    - [ ] git checkout master
